summaryrefslogtreecommitdiffstats
path: root/src/H5Fmpi.c
diff options
context:
space:
mode:
authorjhendersonHDF <jhenderson@hdfgroup.org>2023-11-03 02:42:28 (GMT)
committerGitHub <noreply@github.com>2023-11-03 02:42:28 (GMT)
commit7404b57da68e92bd28c5da2053830e7cbfe032d1 (patch)
treed9d939f5b64657c2f47181e7e09f221d1007bbeb /src/H5Fmpi.c
parent61982b60fd5e3a29044a1cdd1931b0ab9f96dec1 (diff)
downloadhdf5-7404b57da68e92bd28c5da2053830e7cbfe032d1.zip
hdf5-7404b57da68e92bd28c5da2053830e7cbfe032d1.tar.gz
hdf5-7404b57da68e92bd28c5da2053830e7cbfe032d1.tar.bz2
Rework MPI Info FAPL preserve PR to use VFD 'ctl' operations (#3782)
Diffstat (limited to 'src/H5Fmpi.c')
-rw-r--r--src/H5Fmpi.c34
1 files changed, 30 insertions, 4 deletions
diff --git a/src/H5Fmpi.c b/src/H5Fmpi.c
index 8a8fdc1..7a535e9 100644
--- a/src/H5Fmpi.c
+++ b/src/H5Fmpi.c
@@ -97,11 +97,10 @@ done:
/*-------------------------------------------------------------------------
* Function: H5F_mpi_get_comm
*
* Purpose: Retrieves the file's communicator
*
- * Return: Success: The communicator (non-negative)
- *
- * Failure: Negative
+ * Return: Success: The communicator object
+ * Failure: MPI_COMM_NULL
*
*-------------------------------------------------------------------------
*/
@@ -123,6 +122,33 @@ done:
} /* end H5F_mpi_get_comm() */
/*-------------------------------------------------------------------------
+ * Function: H5F_mpi_get_info
+ *
+ * Purpose: Retrieves the file's MPI_Info info object
+ *
+ * Return: Success: The info object
+ * Failure: MPI_INFO_NULL
+ *
+ *-------------------------------------------------------------------------
+ */
+MPI_Info
+H5F_mpi_get_info(const H5F_t *f)
+{
+ MPI_Info ret_value = MPI_INFO_NULL;
+
+ FUNC_ENTER_NOAPI(MPI_INFO_NULL)
+
+ assert(f && f->shared);
+
+ /* Dispatch to driver */
+ if ((ret_value = H5FD_mpi_get_info(f->shared->lf)) == MPI_INFO_NULL)
+ HGOTO_ERROR(H5E_FILE, H5E_CANTGET, MPI_INFO_NULL, "driver get_info request failed");
+
+done:
+ FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5F_mpi_get_info() */
+
+/*-------------------------------------------------------------------------
* Function: H5F_shared_mpi_get_size
*
* Purpose: Retrieves the size of an MPI process.
@@ -97,11 +97,10 @@ done:
* Function: H5F_mpi_get_comm
*
- * Purpose: Retrieves the file's communicator
+ * Purpose: Retrieves the file's MPI_Comm communicator object
*